polyfemos.back.filewriter.STFWriter — polyfemos 0.3.29 documentation

# polyfemos.back.filewriter.STFWriter

class `polyfemos.back.filewriter.` `STFWriter`(*args, **kwargs)

  Bases: `polyfemos.back.filewriter.FileWriter`

  State of health text file (‘*.stf’) writer

  Public Methods

  `__init__`(*args, **kwargs)

    `self._file_writing_func` is set to `write_file()`.

    `self._create_line_func` is set to `create_stfline()`.

    See `__init__()` for more info.

  `append_line`(filename, line)

    If there is no file with a name `filename` in `self._dict`, header is added to the corersponding file entry in `self._dict`.

    Parameters

      - filename (str) –

      - line (str) – Line to be appended into the file (`filename`) entry in `self._dict`.